==> terasoluna-batch4j-blank_2.0.0.3.zip: jp/terasoluna/fw/file/dao/standard/NullColumnParser.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.fw.file.dao.standard;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

/**
 * p[YsȂȂJp[U[NXB
 * 
 * <p>
 * ϊʂt@CsIuWFNgString^̑ɒli[B
 * </p>
 * 
 * <p>tH[}bǵAB</p>
 * 
 */
public class NullColumnParser implements ColumnParser {

    /**
     * w肳ꂽ̂܂܃t@CsIuWFNgɊi[B
     * 
     * @param column J̕
     * @param t t@CsIuWFNg
     * @param method J̕t@CsIuWFNgɊi[郁\bh
     * @param columnFormat p[Yۂ̃tH[}bg
     * @throws IllegalArgumentException t@CsIuWFNgsetter\bh̃ANZXɎsƂ
     * @throws IllegalAccessException t@CsIuWFNgւ̐ݒ肪sƂ
     * @throws InvocationTargetException t@CsIuWFNg̃\bhOX[Ƃ
     */
    public void parse(String column, Object t, Method method,
            String columnFormat) throws IllegalArgumentException,
            IllegalAccessException, InvocationTargetException {
        method.invoke(t, column);
    }
}

==> terasoluna-batch4j-blank_3.2.0.zip: jp/terasoluna/fw/file/dao/standard/NullColumnParser.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.fw.file.dao.standard;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

/**
 * p[XsȂȂJp[T[NXB
 * <p>
 * ϊʂt@CsIuWFNgString^̑ɒli[B
 * </p>
 * <p>
 * tH[}bǵAB
 * </p>
 */
public class NullColumnParser implements ColumnParser {

    /**
     * w肳ꂽ̂܂܃t@CsIuWFNgɊi[B
     * @param column J̕
     * @param t t@CsIuWFNg
     * @param method J̕t@CsIuWFNgɊi[郁\bh
     * @param columnFormat p[Xۂ̃tH[}bg
     * @throws IllegalArgumentException t@CsIuWFNgsetter\bh̃ANZXɎsƂ
     * @throws IllegalAccessException t@CsIuWFNgւ̐ݒ肪sƂ
     * @throws InvocationTargetException t@CsIuWFNg̃\bhOX[Ƃ
     */
    public void parse(String column, Object t, Method method,
            String columnFormat) throws IllegalArgumentException,
                                IllegalAccessException,
                                InvocationTargetException {
        method.invoke(t, column);
    }
}
